@@ -15,30 +15,38 @@ def plot_scores(output_dir='',cyrange=False):
 			model = int(line[1].split('_')[-1])
 			shifts = line[3]
 			shift_perc = int(line[5])
+			corr_score = float(line[9])
+			rmsd_score = float(line[13])
+			corr_score_wd = float(line[17])
+			rmsd_score_wd = float(line[21])
+		
 			if line[9] != 'nan':
 				if pdb not in data:
 					data[pdb] = {}
 		
 				if shifts not in data[pdb]:
 					if cyrange:
-						data[pdb][shifts] = {'model':[model],'rmsd':[float(line[13])],'corr':[float(line[9])],'rmsd_welldefined':[float(line[21])],'corr_welldefined':[float(line[17])],'shift_perc':[shift_perc]}
+						if str(corr_score_wd) != 'nan':
+							data[pdb][shifts] = {'model':[model],'rmsd':[rmsd_score],'corr':[corr_score],'rmsd_welldefined':[rmsd_score_wd],'corr_welldefined':[corr_score_wd],'shift_perc':[shift_perc]}
 					else:
-						data[pdb][shifts] = {'model':[model],'rmsd':[float(line[13])],'corr':[float(line[9])],'shift_perc':[shift_perc]}
+						if str(corr_score) != 'nan':
+							data[pdb][shifts] = {'model':[model],'rmsd':[rmsd_score],'corr':[corr_score],'shift_perc':[shift_perc]}
 
 				else:
-					data[pdb][shifts]['model'].append(model)
-					data[pdb][shifts]['rmsd'].append(float(line[13]))
-					data[pdb][shifts]['corr'].append(float(line[9]))
-					data[pdb][shifts]['shift_perc'].append(shift_perc)
+					if str(corr_score) != 'nan':
+						data[pdb][shifts]['model'].append(model)
+						data[pdb][shifts]['rmsd'].append(rmsd_score)
+						data[pdb][shifts]['corr'].append(corr_score)
+						data[pdb][shifts]['shift_perc'].append(shift_perc)
 					if cyrange:
-						data[pdb][shifts]['rmsd_welldefined'].append(float(line[21]))
-						data[pdb][shifts]['corr_welldefined'].append(float(line[17]))
+						if str(corr_score_wd) != 'nan':
+							data[pdb][shifts]['rmsd_welldefined'].append(rmsd_score_wd)
+							data[pdb][shifts]['corr_welldefined'].append(corr_score_wd)
 
 				
-	n=1
 	for pdb in data:
 		for shifts in data[pdb]:
-			plt.figure(n)
+			plt.cla()
 			plt.scatter(data[pdb][shifts]['rmsd'], data[pdb][shifts]['corr'], c='black',s=8)
 
 			labels = [plt.text(data[pdb][shifts]['rmsd'][i], data[pdb][shifts]['corr'][i], data[pdb][shifts]['model'][i],
